@@ -7,7 +7,8 @@ from typing import (
 
 from pydantic import (
     Extra,
-    Field, PrivateAttr,
+    Field,
+    PrivateAttr,
 )
 from requests import HTTPError
 from yarl import URL
@@ -37,7 +38,7 @@ if TYPE_CHECKING:
         NovelSeriesResult,
     )
 
-__all__ = ['Novel', 'NovelMaker', 'NovelSeries']
+__all__ = ["Novel", "NovelMaker", "NovelSeries"]
 
 
 class Novel(PixivModel):
@@ -47,7 +48,7 @@ class Novel(PixivModel):
     restrict: int
     x_restrict: int
     is_original: bool
-    image_url: ImageUrl = Field(alias='image_urls')
+    image_url: ImageUrl = Field(alias="image_urls")
     create_date: datetime
     tags: List[Tag]
     page_count: int
@@ -63,9 +64,9 @@ class Novel(PixivModel):
     is_mypixiv_only: bool
     is_x_restricted: bool
     comment_access_control: Optional[int]
-    ai_type: AIType = Field(alias='novel_ai_type')
+    ai_type: AIType = Field(alias="novel_ai_type")
 
-    _check = null_dict_validator('series')
+    _check = null_dict_validator("series")
     _is_r18: Optional[bool] = PrivateAttr(None)
 
     @property
@@ -74,30 +75,27 @@ class Novel(PixivModel):
 
     @property
     def link(self) -> URL:
-        return URL(f"https://www.pixiv.net/novel/show.php?id=1{self.id}")
+        return URL(f"https://www.pixiv.net/novel/show.php?id={self.id}")
 
     @property
     def is_r18(self) -> bool:
         if self._is_r18 is None:
             try:
                 from async_pixiv.client import PixivClient
+
                 client = PixivClient.get_client()
-                response = client.sync_request('GET', str(self.link))
+                response = client.sync_request("GET", str(self.link))
                 response.raise_for_status()
                 html = response.text
                 title: str = re.findall(
                     r"<meta property=\"twitter:title\" content=\"(.*?)\">", html
                 )[0]
-                self._is_r18 = title.startswith('[R-18')
+                self._is_r18 = title.startswith("[R-18")
             except HTTPError:
                 self._is_r18 = any(
                     map(
-                        lambda x: (
-                                'R-18' in x.name.upper()
-                                or
-                                'R18' in x.name.upper()
-                        ),
-                        self.tags
+                        lambda x: ("R-18" in x.name.upper() or "R18" in x.name.upper()),
+                        self.tags,
                     )
                 )
 
@@ -108,6 +106,7 @@ class Novel(PixivModel):
     ) -> "NovelContentResult":
         if client is None:
             from async_pixiv.client import PixivClient
+
             client = PixivClient.get_client()
         return await client.NOVEL.content(self.id)
 
@@ -118,9 +117,18 @@ class Novel(PixivModel):
             return None
         if client is None:
             from async_pixiv.client import PixivClient
+
             client = PixivClient.get_client()
         return await client.NOVEL.series(self.series.id)
 
+    def __eq__(self, other: "Novel") -> bool:
+        if not isinstance(other, Novel):
+            return False
+        return self.id == other.id
+
+    def __hash__(self) -> int:
+        return hash(f"pixiv_novel_{self.id}")
+
 
 class NovelMaker(PixivModel):
     page: int
@@ -133,7 +141,7 @@ class NovelSeries(Series):
     caption: str
     is_original: bool
     is_concluded: bool
-    character_count: int = Field(alias='total_character_count')
+    character_count: int = Field(alias="total_character_count")
     user: User
-    display: str = Field(alias='display_text')
+    display: str = Field(alias="display_text")
     watchlist_added: bool
